get_kernel: Helper function that gets a kernel function for kdensity.

View source: R/kernels.R

get_kernelR Documentation

Helper function that gets a kernel function for kdensity.

Description

Helper function that gets a kernel function for kdensity.

Usage

get_kernel(kernel_str)

Arguments

kernel_str

a string specifying which kernel to use.

Value

a kernel function of the format k(u) with integral normalized to 1.


kdensity documentation built on May 5, 2026, 1:06 a.m.