Learn R Programming

kdensity (version 1.0.1)

mlbeta: Estimates the parameter of the Beta distribution using maximum likelihood

Description

Uses stat::nlm to estimate the parameters of the Beta distribution.

Usage

mlbeta(x, start = NULL, type = c("none", "gradient", "hessian"))

Arguments

x

The data from which the estimate is to be computed.

start

Optional starting parameter values for the minimization. Passed to the stats::nlm function.

type

Whether a dedicated gradient or hessian should be passed to stats::nlm.

Value

A named numeric vector with maximum likelihood estimates for shape1 and shap2.

Details

For type, the option none is fastest.