Learn R Programming

kdensity (version 1.0.1)

mlgamma: Estimates the parameter of the Gamma distribution using maximum likelihood

Description

Uses Newton-Raphson to estimate the parameters of the Gamma distribution.

Usage

mlgamma(x, rel.tol = .Machine$double.eps^0.25, iterlim = 100)

Arguments

x

The data from which the estimate is to be computed.

rel.tol

Relative accuracy requested.

iterlim

A positive integer specifying the maximum number of iterations to be performed before the program is terminated.

Value

A named numeric vector with maximum likelihood estimates for shape and rate.

References

Choi, S. C, and R. Wette. "Maximum likelihood estimation of the parameters of the gamma distribution and their bias." Technometrics 11.4 (1969): 683-690.