Learn R Programming

kdensity (version 1.0.1)

mlgumbel: Estimates the parameter of a Gumbel distribution by maximum likelihood

Description

Uses Newton-Raphson to estimate the parameters of the Gumbel distribution.

Usage

mlgumbel(x, scale0 = 1, rel.tol = .Machine$double.eps^0.25,
  iterlim = 100)

Arguments

x

The data from which the estimate is to be computed.

scale0

An optional starting value for the scale parameter.

rel.tol

Relative accuracy requested.

iterlim

A positive integer specifying the maximum number of iterations to be performed before the program is terminated.

Value

A named numeric vector with maximum likelihood estimates for shape and scale.