Uses Newton-Raphson to estimate the parameters of the Kumaraswamy distribution.
mlkumar(x, a0 = 1, rel.tol = .Machine$double.eps^0.25, iterlim = 100)The data from which the estimate is to be computed.
An optional starting value for the a parameter.
Relative accuracy requested.
A positive integer specifying the maximum number of iterations to be performed before the program is terminated.
A named numeric vector with maximum likelihood estimates for
a and b.
Jones, M. C. "Kumaraswamy's distribution: A beta-type distribution with some tractability advantages." Statistical Methodology 6.1 (2009): 70-81.
Kumaraswamy, Ponnambalam. "A generalized probability density function for double-bounded random processes." Journal of Hydrology 46.1-2 (1980): 79-88.