Learn R Programming

kdensity (version 1.0.1)

mlweibull: Estimates the parameter of a Weibull distribution by maximum likelihood

Description

Uses Newton-Raphson to estimate the parameters of the Weibull distribution.

Usage

mlweibull(x, shape0 = 2, rel.tol = .Machine$double.eps^0.25,
  iterlim = 100)

Arguments

x

The data from which the estimate is to be computed.

shape0

An optional starting value for the shape parameter.

rel.tol

Relative accuracy requested.

iterlim

A positive integer specifying the maximum number of iterations to be performed before the program is terminated.

Value

A named numeric vector with maximum likelihood estimates for shape and scale.