Uses stat::nlm to estimate the parameters of the Beta distribution.
mlbeta(x, start = NULL, type = c("none", "gradient", "hessian"))The data from which the estimate is to be computed.
Optional starting parameter values for the minimization.
Passed to the stats::nlm function.
Whether a dedicated gradient or hessian should be
passed to stats::nlm.
A named numeric vector with maximum likelihood estimates for
shape1 and shap2.
For type, the option none is fastest.