Uses Newton-Raphson to estimate the parameters of the Gamma distribution.
mlgamma(x, rel.tol = .Machine$double.eps^0.25, iterlim = 100)The data from which the estimate is to be computed.
Relative accuracy requested.
A positive integer specifying the maximum number of iterations to be performed before the program is terminated.
A named numeric vector with maximum likelihood estimates for
shape and rate.
Choi, S. C, and R. Wette. "Maximum likelihood estimation of the parameters of the gamma distribution and their bias." Technometrics 11.4 (1969): 683-690.