Uses Newton-Raphson to estimate the parameters of the Gumbel distribution.
mlgumbel(x, scale0 = 1, rel.tol = .Machine$double.eps^0.25,
iterlim = 100)The data from which the estimate is to be computed.
An optional starting value for the scale parameter.
Relative accuracy requested.
A positive integer specifying the maximum number of iterations to be performed before the program is terminated.
A named numeric vector with maximum likelihood estimates for
shape and scale.